import pymongo

from conexao.ssh import start_forward
from conexao.config import config


def create_client(profile_name: str) -> pymongo.MongoClient:
    '''Returns a Mongo Client for a configured profile.'''
    profile = config['profiles'][profile_name]

    if ssh := profile.get('ssh'):
        socket = start_forward(ssh['host'], ssh['forwards'])
        profile['mongo']['host'] = profile['mongo']['host'].format(socket=socket)

    return pymongo.MongoClient(**profile['mongo'])



from conexao.ssh import start_forward


def start_docker_forward(host):
    '''Creates an SSH forward to a Docker in a host and returns the path to its
    local socket.'''
    return start_forward(host, '{socket}:/var/run/docker.sock')



"""
Setup.
"""

import setuptools

setuptools.setup(
    name="conexao",
    version="0.0.1",
    description="A connection helper.",
    packages=setuptools.find_packages(exclude=["tests*"]),
    scripts=['bin/conexao'],
    # install_requires=[],
)
